/*
    $Id: bsc.c,v 1.2 1999/07/11 00:26:02 james Exp $

    bsc, Videopad Commute Logger
    Copyright (C) 1999  James Cameron  (quozl@us.netrek.org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef lint
static char vcid[] = "$Id: bsc.c,v 1.2 1999/07/11 00:26:02 james Exp $";
#endif /* lint */

/*
    Provides disk logging for the commute application on the Videopad, which
    records travel times between checkpoints on a regular driving path.
*/

#include <stdio.h>
#include <ctype.h>
#include <time.h>
#include <string.h>

#include "bsc.h"

#define MAXMSG 2048

char response[MAXMSG];

char *bsc ( int rlun, const char *pdu, int length )
{
  char *token;
  char message[MAXMSG];
  
  memcpy ( message, pdu, length );
  message[length] = '\0';
  
  if ( message[0] != '|' ) return NULL;
  if ( message[1] != '|' ) return NULL;
  
  token = strtok ( message, "|" );
  if ( strcmp ( token, "commute" ) ) return NULL;
  
  token = strtok ( NULL, "|" );
  
  /* ||commute|time */
  if ( ! strcmp ( token, "time" ) ) {
    static char buffer[64];
    
    time_t now = time ( NULL );
    struct tm *tm = localtime ( &now );
    
    sprintf ( buffer, "||commute|time|%d|%d|%d|%d|%d|%d",
	      tm->tm_year, tm->tm_mon+1, tm->tm_mday,
	      tm->tm_hour, tm->tm_min, tm->tm_sec );
    
    printf ( "%s\n", buffer );
    return buffer;
  }
  
  /* ||commute|dump|data */
  if ( ! strcmp ( token, "dump" ) ) {
    FILE *file;
    time_t now = time ( NULL );
    struct tm *tm = localtime ( &now );
    char name[132];
    
    sprintf ( name, "commute-%04.4d-%02.2d-%02.2d.txt",
	      tm->tm_year+1900, tm->tm_mon+1, tm->tm_mday );
    
    /* prefer appending to file rather than writing new one */
    file = fopen ( name, "a" );
    if ( file == NULL ) file = fopen ( name, "w" );
    if ( file != NULL ) {
      token = strtok ( NULL, "|" );
      while ( token != NULL ) {
	fprintf ( file, "%s", token );
	token = strtok ( NULL, "|" );
      }
      fclose ( file );
      return "||commute|dump|ok";
    }
    perror ( "bs: commute: dump: fopen" );
    return "||commute|dump|fail";
  }
  
  printf ( "unknown token: %s\n", token );
  return "unknown commute request";
}
